# Pup Quiz

**Pup Quiz** facilitates vocabulary acquisition by employing [spaced repetition](https://en.wikipedia.org/wiki/Spaced_repetition) principles, quizzing words in a systematic order where words in a critical state are quizzed the most often, followed by a bucket of new words and then buckets of words of descending criticalness.

```
pip install pupquiz
```
